@@ -1,14 +1,19 @@
 {
     'name': "Easy My Coop Spain",
-    'version': '12.0.0.0.2',
-    'depends': ['easy_my_coop', 'easy_my_coop_website'],
+    'version': '12.0.0.0.6',
+    'depends': [
+        'easy_my_coop',
+        'easy_my_coop_website'
+    ],
     'author': "Coopdevs Treball SCCL",
+    'website': 'https://coopdevs.org',
     'category': "Cooperative management",
     'description': """
     Easy My Coop localization for Spain
     """,
     "license": "AGPL-3",
     'data': [
+        "views/become_company_cooperator_view.xml",
         "views/become_cooperator_view.xml",
         "views/subscription_request_view.xml",
     ],
